'---------------------------------------------------------------------------------------------------------
' Generic script to update an ADM template in a) Specific GPOs, b) Windows Inf and c) Type Manager
' and to update the lists Type Manager uses to determine which ADMs are loaded when editing which GPOs. 
' IMB 10/9/08
'---------------------------------------------------------------------------------------------------------

On Error resume next
'Option Explicit

Dim oShell, oFSO, sScriptDirectory, sAdmFileSource, iLength, iReturn, sDomain, TM_ADM_Folder_Path, TM_ADM_Folder, sTMList, sInfAdm, sADM

set oShell = wscript.createObject("wscript.shell")
Set oFSO = CreateObject("Scripting.FileSystemObject")

sRMManage = oShell.RegRead("HKLM\Software\Research Machines\Installation\Locations\RMManage")

Dim aUserGPOs, aStationGPOs
Dim str1
Dim newTxt
dim regex

'******************************************************
'**                                                  **
'**               CONFIGURATION DATA                 **    
'**                                                  **
'**      Only edit the variables in this section     **
'**                                                  **
'**                                                  **
'******************************************************


' List the User GPOs to have this adm template added	
aUserGPOs = Array() 


' List the Station GPOs to have this adm template added	
aStationGPOs = Array() 


' Enter the name of the adm file that we're updating. 
' Ensure that this is THE EXACT FILE NAME!

sADM="RM Tutor 5 Policies.adm"


'Set flags to determine whether Type Manager should load 
'the adm when editing different Registry Policies.

bTypeManInternetList = false        ' Loaded when the Internet & Email GPO is edited
bTypeManUserList =  true          ' Loaded when UserTypes and the All Users GPO are edited
bTypeManStationList = true ' Loaded when StationTypes and the All Stations GPO are edited



'******************************************************
'**                                                  **
'**           END OF CONFIGURATION DATA              **    
'**                                                  **
'**                                                  **
'******************************************************



' set up logging and log first message
sLogDirectory = oShell.RegRead("HKLM\Software\Research Machines\LogSettings\ComponentLogPath")
sLogfile = sLogDirectory & "\ADM Updater.log"

sMsg = "****************************************"
LogMsg sMsg, sLogfile, True



' Get the path to the where the script is running from. 
' ADM Templates will be in the same directory as this.

'sScriptDirectory = oFSO.GetAbsolutePathName(".")
sScriptDirectory = wscript.scriptfullname

sscriptDirectory = replace(sscriptDirectory, "\ADMUpdater.vbs", "",1 ,-1, 1)


'iLength = Len(sScriptDirectory)
'If Right(sScriptDirectory, 1) = "\" Then
'	sScriptDirectory = Left(sScriptDirectory, iLength - 1)
'End If

sMsg = "Installing from " & sScriptDirectory
LogMsg sMsg, sLogfile, True

'set source file to be the new adm file
sAdmFileSource = sScriptDirectory & "\" & sADM



'Connect to domain


sMsg = "Connecting to domain"
LogMsg sMsg, sLogfile, True



Dim oDSE, oPolicies, oPolicy, sPolFile, sFile
Set oDSE = GetObject("LDAP://RootDSE")
sDomain = oDSE.Get("defaultNamingContext")


'Connect to policy container (where GPOs are stored in AD)

sMsg = "Locating policies container"
LogMsg sMsg, sLogfile, True

Set oPolicies = GetObject("LDAP://CN=Policies,CN=System," & sDomain)



'Copy ADM to the Policy Objects(s) listed in the arrays

sMsg = "Beginning loop through User GPOs"
LogMsg sMsg, sLogfile, True


For x = LBound(aUserGPOs) To UBound(aUserGPOs)
	sGPO = aUserGPOs(x)

	For Each oPolicy In oPolicies                       
		If oPolicy.DisplayName = sGPO Then
	
	   'Need to find path to GPO ADM folder
       		sAdmFile = oPolicy.gPCFileSysPath & "\adm\" & sADM

		
		
		'Log message to say we are copying file
		sMsg = "Copying " & sAdmFileSource & " to " & sAdmFile
		LogMsg sMsg, sLogfile, True
		' copy new file
		

		oFSO.CopyFile sAdmFileSource, sAdmFile

		'set to read-only,archive,hidden
		set f = oFSO.GetFile(sAdmFile)



		f.Attributes = 35		

		If Err.Number then
			
	   		LogError("Error copying adm template to " & sGPO & " GPO")
			Err.Clear
		End If


	End If
 
	Next

Next

sMsg = "Finished looping through User GPOs"
LogMsg sMsg, sLogfile, True
sGPO = ""



sMsg = "Beginning loop through Station GPOs"
LogMsg sMsg, sLogfile, True


For x = LBound(aStationGPOs) To UBound(aStationGPOs)
	sGPO = aStationGPOs(x)

	For Each oPolicy In oPolicies                       
		If oPolicy.DisplayName = sGPO Then
	
	   'Need to find path to GPO ADM folder
       		sAdmFile = oPolicy.gPCFileSysPath & "\adm\" & sADM

	
		
		'Log message to say we are copying file
		sMsg = "Copying " & sAdmFileSource & " to " & sAdmFile
		LogMsg sMsg, sLogfile, True
		set f = oFSO.GetFile (sAdmFile)
		f.Attributes = 0				
		' copy new file
		oFSO.CopyFile sAdmFileSource, sAdmFile

		'set to read-only,archive,hidden
		
		f.Attributes = 35		

		If Err.Number then
			
	   		LogError("Error copying adm template to " & sGPO & " GPO")
			Err.Clear
		End If


	End If
 
	Next

Next

sMsg = "Finished looping through Station GPOs"
LogMsg sMsg, sLogfile, True
sGPO = ""



'*********************************************************
' Add the adm template to C:\WinNT\Inf\Research Machines
'*********************************************************	

'Get windows directory path to allow for 2000 and 2003 machines
sInfAdm = sInfAdm & oShell.ExpandEnvironmentStrings("%WINDIR%")

sInfAdm = sInfAdm & "\inf\Research Machines\" & sADM

sMsg = "Copying " & sAdmFileSource & " to " & sInfAdm
LogMsg sMsg, sLogfile, True


'copy file to windows\Inf\Research machines directory
oFSO.CopyFile sAdmFileSource, sInfAdm

If Err.Number then
   	LogError("Error copying adm template to Inf directory")
End If

		


'**************************************
'Add template to type manager
'**************************************


'Find path for typemanagers adm files and add new adm
'****************************************************

TM_ADM_Folder_Path = oShell.RegRead("HKLM\Software\Research Machines\Network Management\Type Manager\ADM Folder")

'If typemanager is present then add relevant entries in registry and filesystem 
If Err.Number then
	LogError("Type manager not Present")
	
Else



	TM_ADM_Folder_Path = TM_ADM_Folder_Path & "\" & sADM
	sMsg = "Copying ADM to Type Manager folder" 
	LogMsg sMsg, sLogfile, True
	
	'Copy my ADM to this location
	oFSO.copyFile sAdmFileSource, TM_ADM_Folder_Path


'**************************************************************
'Add the adm to the appropriate list to that it is loaded when 
'editing StationTypes, UserTypes or the Internet & Email GPO
'**************************************************************


	If bTypeManInternetList = True Then
		sMsg = "Adding to Type Manager's Internet & Email adm list in the registry" 
		LogMsg sMsg, sLogfile, True

		'Add my ADM template file name to list in Type manager Reg Key
		sTMList = oShell.RegRead("HKLM\Software\Research Machines\Network Management\Type Manager\Internet & Email ADMs")
	

		'REMOVE TUTOR 4 TEMPLATE IF IT EXISTS
		If InStr(sTMList, "RM Tutor 4 Policies.adm") > 0 then
					
			Set regEx = New RegExp            
			regEx.Pattern = ";RM Tutor 4 Policies.adm"            
			regEx.IgnoreCase = True            
			stmlist = regEx.Replace(stmlist, "")
			oShell.RegWrite"HKLM\Software\Research Machines\Network Management\Type Manager\Internet & Email ADMs", stmlist, "REG_SZ"
			Set T4 = ofso.GetFile(sRMManage & "\Type Manager\ADM\RM Tutor 4 Policies.adm")
			T4.delete
			
		end if	

		'Check ADM is not already listed or Type manager will get confused
			If InStr(sTMList, sADM) > 0 then
				sMsg = sADM & " already present in Type manager's Internet and Email adm list" 
				LogMsg sMsg, sLogfile, True
			Else
		
				sTMList = sTMList & ";" & sADM

				sMsg = "Adding" & sADM & " to Type Manager's Internet and Email adm list" 
				LogMsg sMsg, sLogfile, True

			'oShell.RegWrite "HKLM\Software\Research Machines\Network Management\Type Manager\Internet & Email ADMs", sTMList, "REG_SZ"
			End If

			

	End If



	If bTypeManUserList  = True Then
		sMsg = "Adding to Type Manager's User policies adm lists in the registry" 
		LogMsg sMsg, sLogfile, True

		'Add my ADM template file name to User GPOs list in Type manager Reg Key
		sTMList = oShell.RegRead("HKLM\Software\Research Machines\Network Management\Type Manager\UserType ADMs")
	


		
		'REMOVE TUTOR 4 TEMPLATE IF IT EXISTS
		If InStr(sTMList, "RM Tutor 4 Policies.adm") > 0 then
						
			Set regEx = New RegExp            
			regEx.Pattern = ";RM Tutor 4 Policies.adm"            
			regEx.IgnoreCase = True            
			stmlist = regEx.Replace(stmlist, "")
			oShell.RegWrite"HKLM\Software\Research Machines\Network Management\Type Manager\UserType ADMs", stmlist, "REG_SZ"
			Set T4 = ofso.GetFile(sRMManage & "\Type Manager\ADM\RM Tutor 4 Policies.adm")
			T4.delete
			
		end if	


		'Check ADM is not already listed or Type manager will get confused
			If InStr(sTMList, sADM) > 0 then
				sMsg = sADM & " already present in Type manager's UserType adm list" 
				LogMsg sMsg, sLogfile, True
			Else
		
				sTMList = sTMList & ";" & sADM

				sMsg = "Adding " & sADM & " to Type Manager's UserType adm list" 
				LogMsg sMsg, sLogfile, True

				oShell.RegWrite "HKLM\Software\Research Machines\Network Management\Type Manager\UserType ADMs", sTMList, "REG_SZ"
			End If


		'Add my ADM template file name to the All Users list in Type manager Reg Key
		sTMList = oShell.RegRead("HKLM\Software\Research Machines\Network Management\Type Manager\All Users ADMs")
	
		'REMOVE TUTOR 4 TEMPLATE IF IT EXISTS
		If InStr(sTMList, "RM Tutor 4 Policies.adm") > 0 then
				
			Set regEx = New RegExp            
			regEx.Pattern = ";RM Tutor 4 Policies.adm"            
			regEx.IgnoreCase = True            
			stmlist = regEx.Replace(stmlist, "")
			oShell.RegWrite"HKLM\Software\Research Machines\Network Management\Type Manager\All Users ADMs", stmlist, "REG_SZ"
			Set T4 = ofso.GetFile(sRMManage & "\Type Manager\ADM\RM Tutor 4 Policies.adm")
			T4.delete
			
		end if	
		'Check ADM is not already listed or Type manager will get confused
			If InStr(sTMList, sADM) > 0 then
				sMsg = sADM & " already present in Type manager's All Users adm list" 
				LogMsg sMsg, sLogfile, True
			Else
		
				sTMList = sTMList & ";" & sADM

				sMsg = "Adding " & sADM & " to Type Manager's All Users adm list" 
				LogMsg sMsg, sLogfile, True

				oShell.RegWrite "HKLM\Software\Research Machines\Network Management\Type Manager\All Users ADMs", sTMList, "REG_SZ"
		End If

	End If


	If bTypeManStationList = True Then
		sMsg = "Adding to Type Manager's Station policies adm lists in the registry" 
		LogMsg sMsg, sLogfile, True

		'Add my ADM template file name to Station GPOs list in Type manager Reg Key
		sTMList = oShell.RegRead("HKLM\Software\Research Machines\Network Management\Type Manager\StationType ADMs")


		'REMOVE TUTOR 4 TEMPLATE IF IT EXISTS
		If InStr(sTMList, "RM Tutor 4 Policies.adm") > 0 then
				
		
			Set regEx = New RegExp            
			regEx.Pattern = ";RM Tutor 4 Policies.adm"            
			regEx.IgnoreCase = True            
			stmlist = regEx.Replace(stmlist, "")
			oShell.RegWrite"HKLM\Software\Research Machines\Network Management\Type Manager\StationType ADMs", stmlist, "REG_SZ"
			Set T4 = ofso.GetFile(sRMManage & "\Type Manager\ADM\RM Tutor 4 Policies.adm")
			T4.delete
			
		end if	
	
		'Check ADM is not already listed or Type manager will get confused



			If InStr(sTMList, sADM) > 0 then
				sMsg = sADM & " already present in Type manager's StationType adm list" 
				LogMsg sMsg, sLogfile, True

			Else
		
				sTMList = sTMList & ";" & sADM

				sMsg = "Adding " & sADM & " to Type Manager's StationType adm list" 
				LogMsg sMsg, sLogfile, True

			oShell.RegWrite "HKLM\Software\Research Machines\Network Management\Type Manager\StationType ADMs", sTMList, "REG_SZ"
			End If


		'Add my ADM template file name to the All Users list in Type manager Reg Key
		sTMList = oShell.RegRead("HKLM\Software\Research Machines\Network Management\Type Manager\All Stations ADMs")
	
		'REMOVE TUTOR 4 TEMPLATE IF IT EXISTS
		If InStr(sTMList, "RM Tutor 4 Policies.adm") > 0 then
				
			Set regEx = New RegExp            
			regEx.Pattern = ";RM Tutor 4 Policies.adm"            
			regEx.IgnoreCase = True            
			stmlist = regEx.Replace(stmlist, "")
			oShell.RegWrite"HKLM\Software\Research Machines\Network Management\Type Manager\All Stations ADMs", stmlist, "REG_SZ"
			Set T4 = ofso.GetFile(sRMManage & "\Type Manager\ADM\RM Tutor 4 Policies.adm")
			T4.delete

		
			
		end if	
		'Check ADM is not already listed or Type manager will get confused
			If InStr(sTMList, sADM) > 0 then
				sMsg = sADM & " already present in Type manager's All Stations adm list" 
				LogMsg sMsg, sLogfile, True
			Else
		
				sTMList = sTMList & ";" & sADM

				sMsg = "Adding " & sADM & " to Type Manager's All Stations adm list" 
				LogMsg sMsg, sLogfile, True

			oShell.RegWrite "HKLM\Software\Research Machines\Network Management\Type Manager\All Stations ADMs", sTMList, "REG_SZ"
			End If


	End If



End if



sMsg = "Finishing update to " & sADM & "." & vbCrLf
LogMsg sMsg, sLogfile, True

sMsg = "****************************************" & vbCrLf
LogMsg sMsg, sLogfile, True


sMsg = " "
LogMsg sMsg, sLogfile, True

wscript.quit



'---------------------------------------------
' Write a message to a log file
'---------------------------------------------
Private Function LogMsg(sMsg, sFile, bDate)

	On Error Resume Next

	Dim a

  	Set a = oFSO.OpenTextFile(sFile, 8, True)
  	If bDate Then
    	a.WriteLine (Date & " " & Time & " - " & sMsg)
  	Else
    	a.WriteLine (sMsg)
  	End If
  
  	a.Close

End Function


'---------------------------------------------
' Error logging
'---------------------------------------------
Private Function LogError(sInsert)

	'Creates a message box if required
  	'Call Wscript.Echo( "Error 0x" & CStr(Err.Number) & " " & Err.Description )
	
	'Log Error in the Log file
	sMsg = sInsert & ": Error 0x" & CStr(Err.Number) & " Description: " & Err.Description & vbCr
  	LogMsg sMsg, sLogFile, True
  	
	Err.Clear
		
End Function


